"""
open_field_instances.py
"""
population = [
    # All measurements in milimeters

    # Tabloid OS Engineer
    {'Metadata': 'Title', 'Frame': 'OS Engineer', 'Sheet': 'tabloid',
     'x position': 8, 'y position': 264, 'max width': 254, 'max height': 13},
    {'Metadata': 'Copyright notice', 'Frame': 'OS Engineer', 'Sheet': 'tabloid',
     'x position': 8, 'y position': 38, 'max width': 254, 'max height': 57},
    {'Metadata': 'Organization logo', 'Frame': 'OS Engineer', 'Sheet': 'tabloid',
     'x position': 8, 'y position': 9, 'max width': 180, 'max height': 24},

    # D OS Engineer
    {'Metadata': 'Title', 'Frame': 'OS Engineer', 'Sheet': 'D',
     'x position': 19, 'y position': 584, 'max width': 254, 'max height': 25},
    {'Metadata': 'Copyright notice', 'Frame': 'OS Engineer', 'Sheet': 'D',
     'x position': 330, 'y position': 38, 'max width': 254, 'max height': 57},
    {'Metadata': 'Organization logo', 'Frame': 'OS Engineer', 'Sheet': 'D',
     'x position': 19, 'y position': 38, 'max width': 191, 'max height': 25},

    # D TRI MBSE
    {'Metadata': 'Title', 'Frame': 'TRI MBSE', 'Sheet': 'D',
     'x position': 19, 'y position': 584, 'max width': 254, 'max height': 25},
    {'Metadata': 'Copyright notice', 'Frame': 'TRI MBSE', 'Sheet': 'D',
     'x position': 400, 'y position': 38, 'max width': 254, 'max height': 57},
    {'Metadata': 'Organization logo', 'Frame': 'TRI MBSE', 'Sheet': 'D',
     'x position': 19, 'y position': 38, 'max width': 191, 'max height': 25},
]
